==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/cs.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendář",
    "Todos" : "Úkoly",
    "Personal" : "Osobní",
    "{actor} created calendar {calendar}" : "{actor} vytvořil(a) kalendář {calendar}",
    "You created calendar {calendar}" : "Vytvořil(a",
    "{actor} deleted calendar {calendar}" : "{actor} smazal(a) kalendář {calendar}",
    "You deleted calendar {calendar}" : "Smazal(a) jste kalendář {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} aktualizoval(a) kalendář {calendar}",
    "You updated calendar {calendar}" : "Aktualizoval(a) jste kalendář {calendar}",
    "You shared calendar {calendar} as public link" : "Sdílel(a) jste kalendář {calendar} jako veřejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstranil(a) jste veřejný odkaz pro kalendář {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} s vámi nasdílel(a) kalendář {calendar}",
    "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začal(a) sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} začal sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} s vámi přestal(a) sdílet kalendář {calendar}",
    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestal(a) sdílet kalendář {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal sdílet kalendář {calendar} sám se sebou",
    "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začal(a) sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} nasdílel(a) kalendář {calendar} skupině {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušil(a) jste sdílení kalendáře {calendar} skupině {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořil(a) událost {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
    "You deleted event {event} from calendar {calendar}" : "Smazal(a) jste událost {event} z kalendáře {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizoval(a) jste událost {event} v kalendáři {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvořil(a) v seznamu {calendar} vytvořila úkol {todo}",
    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořil(a) úkol {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} smazal(a) úkol {todo} ze seznamu {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {todo} jste smazal(a) úkol {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
    "You updated todo {todo} in list {calendar}" : "Aktualizoval(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyřešil(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřel(a) úkol {todo} v seznamu {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
    "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
    "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
    "Contact birthdays" : "Narozeniny kontaktů",
    "%s via %s" : "%s přes %s",
    "Invitation canceled" : "Pozvánka zrušena",
    "Hello %s," : "Dobrý den %s,",
    "The meeting »%s« with %s was canceled." : "Setkání »%s« s %s bylo zrušeno.",
    "Invitation updated" : "Pozvánka aktualizována",
    "The meeting »%s« with %s was updated." : "Setkání »%s« s %s bylo aktualizováno.",
    "%s invited you to »%s«" : "%s vás zve na »%s«",
    "When:" : "Kdy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Contacts" : "Kontakty",
    "Technical details" : "Technické detaily",
    "Remote Address: %s" : "Vzdálená adresa: %s",
    "Request ID: %s" : "ID požadavku: %s",
    "CalDAV server" : "CalDAV server",
    "Send invitations to attendees" : "Poslat pozvánky na adresy účastníků",
    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/cs.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendář",
    "Todos" : "Úkoly",
    "Personal" : "Osobní",
    "{actor} created calendar {calendar}" : "{actor} vytvořil(a) kalendář {calendar}",
    "You created calendar {calendar}" : "Vytvořil(a",
    "{actor} deleted calendar {calendar}" : "{actor} smazal(a) kalendář {calendar}",
    "You deleted calendar {calendar}" : "Smazal(a) jste kalendář {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} aktualizoval(a) kalendář {calendar}",
    "You updated calendar {calendar}" : "Aktualizoval(a) jste kalendář {calendar}",
    "You shared calendar {calendar} as public link" : "Sdílel(a) jste kalendář {calendar} jako veřejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstranil(a) jste veřejný odkaz pro kalendář {calendar} ",
    "{actor} shared calendar {calendar} with you" : "{actor} s vámi nasdílel(a) kalendář {calendar}",
    "You shared calendar {calendar} with {user}" : "S uživatelem {user} jste začal(a) sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} začal sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} s vámi přestal(a) sdílet kalendář {calendar}",
    "You unshared calendar {calendar} from {user}" : "S uživatelem {user} jste přestal(a) sdílet kalendář {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} přestal(a) sdílet kalendář {calendar} s uživatelem {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} přestal sdílet kalendář {calendar} sám se sebou",
    "You shared calendar {calendar} with group {group}" : "Se skupinou {group} jste začal(a) sdílet kalendář {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} nasdílel(a) kalendář {calendar} skupině {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušil(a) jste sdílení kalendáře {calendar} skupině {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} přestal(a) sdílet kalendář {calendar} se skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvořil(a) událost {event} v kalendáři {calendar}",
    "You created event {event} in calendar {calendar}" : "V kalendáři {calendar} jste vytvořil(a) událost {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} z kalendáře {calendar} smazal(a) událost {event}",
    "You deleted event {event} from calendar {calendar}" : "Smazal(a) jste událost {event} z kalendáře {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} aktualizoval(a) událost {event} v kalendáři {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizoval(a) jste událost {event} v kalendáři {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvořil(a) v seznamu {calendar} vytvořila úkol {todo}",
    "You created todo {todo} in list {calendar}" : "V seznamu {calendar} jste vytvořil(a) úkol {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} smazal(a) úkol {todo} ze seznamu {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Ze seznamu {todo} jste smazal(a) úkol {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} aktualizoval(a) úkol {todo} v seznamu {calendar}",
    "You updated todo {todo} in list {calendar}" : "Aktualizoval(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyřešil(a) úkol {todo} v seznamu {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyřešil(a) jste úkol {todo} v seznamu {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otevřel(a) úkol {todo} v seznamu {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Znovu jste otevřel(a) úkol {todo} v seznamu {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendář</strong> byl změněn",
    "A calendar <strong>event</strong> was modified" : "<strong>Událost</strong> v kalendáři byla změněna",
    "A calendar <strong>todo</strong> was modified" : "<strong>Úkol</strong> v kalendáři byl změněn",
    "Contact birthdays" : "Narozeniny kontaktů",
    "%s via %s" : "%s přes %s",
    "Invitation canceled" : "Pozvánka zrušena",
    "Hello %s," : "Dobrý den %s,",
    "The meeting »%s« with %s was canceled." : "Setkání »%s« s %s bylo zrušeno.",
    "Invitation updated" : "Pozvánka aktualizována",
    "The meeting »%s« with %s was updated." : "Setkání »%s« s %s bylo aktualizováno.",
    "%s invited you to »%s«" : "%s vás zve na »%s«",
    "When:" : "Kdy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Contacts" : "Kontakty",
    "WebDAV" : "WebDAV",
    "Technical details" : "Technické detaily",
    "Remote Address: %s" : "Vzdálená adresa: %s",
    "Request ID: %s" : "ID požadavku: %s",
    "CalDAV server" : "CalDAV server",
    "Send invitations to attendees" : "Poslat pozvánky na adresy účastníků",
    "Please make sure to properly set up the email settings above." : "Ujistěte se, že jste správně nastavili výše uvedená nastavení e-mailu.",
    "Automatically generate a birthday calendar" : "Automaticky vytvořit kalendář s narozeninami"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
